summaryrefslogtreecommitdiff
path: root/cli/cli/context.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'cli/cli/context.hxx')
-rw-r--r--cli/cli/context.hxx9
1 files changed, 6 insertions, 3 deletions
diff --git a/cli/cli/context.hxx b/cli/cli/context.hxx
index 66dcb24..19bfa51 100644
--- a/cli/cli/context.hxx
+++ b/cli/cli/context.hxx
@@ -153,10 +153,13 @@ public:
string
process_link_target (const string&);
// Translate and format the documentation string. Translate converts
// the <arg>-style constructs to \i{arg}. Format converts the string
// to the output format.
//
+ static void
+ preprocess_ascii_tree (string&);
+
static string
translate_arg (string const&, std::set<string>&);
@@ -153,10 +153,13 @@ public:
string
process_link_target (const string&);
- // Translate and format the documentation string. Translate converts
- // the <arg>-style constructs to \i{arg}. Format converts the string
- // to the output format.
+ // Preprocess, translate, and format the documentation string. Translate
+ // converts the <arg>-style constructs to \i{arg}. Format converts the
+ // string to the output format.
//